@@ -24,10 +24,8 @@ use tiny_keccak::{Hasher, Sha3};
 
 use eyre::{eyre, Context, Result};
 use safe_network::{
-    client::{
-        utils::generate_random_vector, utils::test_utils::read_network_conn_info, Client, Config,
-    },
-    types::ChunkAddress,
+    client::{client_api::BlobAddress, utils::test_utils::read_network_conn_info, Client, Config},
+    types::utils::random_bytes,
     url::{ContentType, Scope, Url, DEFAULT_XORURL_BASE},
 };
 
@@ -156,7 +154,7 @@ pub async fn run_split() -> Result<()> {
 
     let files_to_put: i32 = 12;
     for _i in 0..files_to_put {
-        let (address, hash) = put_data().await?;
+        let (address, hash) = upload_data().await?;
         all_data_put.push((address, hash));
     }
 
@@ -182,24 +180,22 @@ pub async fn run_split() -> Result<()> {
     sleep(interval_duration).await;
 
     // now we read the data
-    let bootstrap_contacts = read_network_conn_info()
-        .context("Could not read network bootstrap".to_string())?
-        .into_iter()
-        .collect();
+    let bootstrap_nodes =
+        read_network_conn_info().context("Could not read network bootstrap".to_string())?;
 
-    let config = Config::new(None, Some(bootstrap_contacts), None, Some(QUERY_TIMEOUT)).await;
-    let client = Client::new(None, config).await?;
+    let config = Config::new(None, None, None, Some(QUERY_TIMEOUT)).await;
+    let client = Client::new(config, bootstrap_nodes, None).await?;
 
     for (address, hash) in all_data_put {
         println!("...fetching Blob at address {:?} ...", address);
-        let mut data = client.read_blob(address, None, None).await;
+        let mut data = client.read_blob(address).await;
 
         let mut attempts = 0;
         while data.is_err() && attempts < 10 {
             attempts += 1;
             // do some retries to ensure we're not just timing out by chance
             sleep(Duration::from_secs(1)).await;
-            data = client.read_blob(address, None, None).await;
+            data = client.read_blob(address).await;
         }
 
         let data = data?;
@@ -218,19 +214,17 @@ pub async fn run_split() -> Result<()> {
     Ok(())
 }
 
-async fn put_data() -> Result<(ChunkAddress, [u8; 32])> {
-    // Now we PUT data.
+async fn upload_data() -> Result<(BlobAddress, [u8; 32])> {
+    // Now we upload the data.
     println!("Reading network bootstrap information...");
-    let bootstrap_contacts = read_network_conn_info()
-        .context("Could not read network bootstrap".to_string())?
-        .into_iter()
-        .collect();
+    let bootstrap_nodes =
+        read_network_conn_info().context("Could not read network bootstrap".to_string())?;
 
-    println!("Creating a Client to connect to {:?}", bootstrap_contacts);
-    let config = Config::new(None, Some(bootstrap_contacts), None, Some(QUERY_TIMEOUT)).await;
-    let client = Client::new(None, config).await?;
+    println!("Creating a Client to connect to {:?}", bootstrap_nodes);
+    let config = Config::new(None, None, None, Some(QUERY_TIMEOUT)).await;
+    let client = Client::new(config, bootstrap_nodes, None).await?;
 
-    let raw_data = generate_random_vector::<u8>(1024 * 1024);
+    let raw_data = random_bytes(1024 * 1024);
 
     let mut hasher = Sha3::v256();
     let mut output = [0; 32];
@@ -239,10 +233,10 @@ async fn put_data() -> Result<(ChunkAddress, [u8; 32])> {
 
     println!("Storing data w/ hash {:?}", output);
 
-    let address = client.store_public_blob(&raw_data).await?;
+    let address = client.write_to_network(raw_data, Scope::Public).await?;
     let xorurl = Url::encode_blob(
         *address.name(),
-        Scope::Public,
+        address.scope(),
         ContentType::Raw,
         DEFAULT_XORURL_BASE,
     )?;
@@ -253,14 +247,14 @@ async fn put_data() -> Result<(ChunkAddress, [u8; 32])> {
     sleep(Duration::from_secs(delay)).await;
 
     println!("...fetching Blob from the network now...");
-    let mut data = client.read_blob(address, None, None).await;
+    let mut data = client.read_blob(address).await;
 
     let mut attempts = 0;
     while data.is_err() && attempts < 10 {
         attempts += 1;
         // do some retries to ensure we're not just timing out by chance
         sleep(Duration::from_secs(1)).await;
-        data = client.read_blob(address, None, None).await;
+        data = client.read_blob(address).await;
     }
 
     let _data = data?;
