@@ -6,35 +6,36 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use crate::client::Error;
+use crate::client::{Error, Result};
 use qp2p::Config as QuicP2pConfig;
 use serde::{Deserialize, Serialize};
 use std::{
     net::{Ipv4Addr, SocketAddr},
-    path::Path,
+    path::{Path, PathBuf},
     time::Duration,
 };
-use tokio::fs::File;
-use tokio::io::AsyncReadExt;
+use tokio::{
+    fs::File,
+    io::{self, AsyncReadExt},
+};
 use tracing::{debug, warn};
 
-const DEFAULT_LOCAL_ADDR: (Ipv4Addr, u16) = (Ipv4Addr::LOCALHOST, 0);
+const DEFAULT_LOCAL_ADDR: (Ipv4Addr, u16) = (Ipv4Addr::UNSPECIFIED, 0);
 
 /// Defaul amount of time to wait for responses to queries before giving up and returning an error.
 pub const DEFAULT_QUERY_TIMEOUT: Duration = Duration::from_secs(90);
 
+const DEFAULT_ROOT_DIR_NAME: &str = "root_dir";
+
 /// Configuration for sn_client.
 #[derive(Clone, Debug, Deserialize, Serialize, Eq, PartialEq)]
 pub struct Config {
     /// The local address to bind to.
     pub local_addr: SocketAddr,
-
-    /// Initial network contacts.
-    pub bootstrap_nodes: Vec<SocketAddr>,
-
+    /// Path to local storage.
+    pub root_dir: PathBuf,
     /// QuicP2p options.
     pub qp2p: QuicP2pConfig,
-
     /// The amount of time to wait for responses to queries before giving up and returning an error.
     pub query_timeout: Duration,
 }
@@ -51,11 +52,14 @@ impl Config {
     ///
     /// If `query_timeout` is not specified, [`DEFAULT_QUERY_TIMEOUT`] will be used.
     pub async fn new(
+        root_dir: Option<&Path>,
         local_addr: Option<SocketAddr>,
-        bootstrap_nodes: Option<Vec<SocketAddr>>,
         config_file_path: Option<&Path>,
         query_timeout: Option<Duration>,
     ) -> Self {
+        let root_dir = root_dir
+            .map(|p| p.to_path_buf())
+            .unwrap_or_else(default_dir);
         // If a config file path was provided we try to read it,
         // otherwise we use default qp2p config.
         let qp2p = match &config_file_path {
@@ -65,7 +69,7 @@ impl Config {
 
         Self {
             local_addr: local_addr.unwrap_or_else(|| SocketAddr::from(DEFAULT_LOCAL_ADDR)),
-            bootstrap_nodes: bootstrap_nodes.unwrap_or_default(),
+            root_dir: root_dir.clone(),
             qp2p,
             query_timeout: query_timeout.unwrap_or(DEFAULT_QUERY_TIMEOUT),
         }
@@ -76,7 +80,7 @@ impl Default for Config {
     fn default() -> Self {
         Self {
             local_addr: SocketAddr::from(DEFAULT_LOCAL_ADDR),
-            bootstrap_nodes: Default::default(),
+            root_dir: default_dir(),
             qp2p: Default::default(),
             query_timeout: Default::default(),
         }
@@ -100,14 +104,33 @@ async fn read_config_file(filepath: &Path) -> Result<QuicP2pConfig, Error> {
     })
 }
 
+/// Root directory for dbs and cached state. If not set, it defaults to
+/// `DEFAULT_ROOT_DIR_NAME` within the project's data directory (see `Config::root_dir` for the
+/// directories on each platform).
+fn default_dir() -> PathBuf {
+    project_dirs()
+        .unwrap_or_default()
+        .join(DEFAULT_ROOT_DIR_NAME)
+}
+
+fn project_dirs() -> Result<PathBuf> {
+    let mut home_dir = dirs_next::home_dir()
+        .ok_or_else(|| io::Error::new(io::ErrorKind::NotFound, "Home directory not found"))?;
+
+    home_dir.push(".safe");
+    home_dir.push("client");
+
+    Ok(home_dir)
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
     use crate::client::utils::test_utils::init_logger;
     use eyre::Result;
     use rand::{distributions::Alphanumeric, thread_rng, Rng};
-    use std::env::temp_dir;
     use std::fs::File;
+    use tempfile::tempdir;
     use tokio::fs::create_dir_all;
 
     // 1. Verify that `Config::new()` generates the correct default config
@@ -117,19 +140,19 @@ mod tests {
     // 3. Assert that `Config::new()` reads the default config written to disk.
     // 4. Verify that `Config::new()` returns the correct default config when no path is provided.
     #[tokio::test(flavor = "multi_thread")]
-    #[ignore]
     async fn custom_config_path() -> Result<()> {
         init_logger();
 
-        let path = temp_dir();
-        let random_filename: String = thread_rng().sample_iter(&Alphanumeric).take(15).collect();
-        let config_filepath = path.join(random_filename);
+        let temp_dir = tempdir().map_err(|e| Error::Generic(e.to_string()))?;
+        let root_dir = temp_dir.path().to_path_buf();
+        let cfg_filename: String = thread_rng().sample_iter(&Alphanumeric).take(15).collect();
+        let config_filepath = root_dir.join(&cfg_filename);
 
         // In the absence of a config file, the config handler
         // should initialize bootstrap_cache_dir only
-        let config = Config::new(None, None, Some(&config_filepath), None).await;
+        let config = Config::new(Some(&root_dir), None, Some(&config_filepath), None).await;
         // convert to string for assert
-        let mut str_path = path
+        let mut str_path = root_dir
             .to_str()
             .ok_or(eyre::eyre!("No path for to_str".to_string()))?
             .to_string();
@@ -139,14 +162,14 @@ mod tests {
         }
 
         let expected_config = Config {
-            local_addr: (Ipv4Addr::LOCALHOST, 0).into(),
-            bootstrap_nodes: vec![],
+            local_addr: (Ipv4Addr::UNSPECIFIED, 0).into(),
+            root_dir: root_dir.clone(),
             qp2p: QuicP2pConfig::default(),
             query_timeout: DEFAULT_QUERY_TIMEOUT,
         };
         assert_eq!(config, expected_config);
 
-        create_dir_all(path).await?;
+        create_dir_all(&root_dir).await?;
         let mut file = File::create(&config_filepath)?;
 
         let config_on_disk = Config::default();
