@@ -10,17 +10,29 @@ use super::{QueryResult, Session};
 
 use crate::client::Error;
 use crate::messaging::{
-    data::{ChunkRead, DataQuery, QueryResponse},
+    data::{CmdError, DataQuery, QueryResponse},
+    signature_aggregator::SignatureAggregator,
     DstLocation, MessageId, MsgKind, ServiceAuth, WireMsg,
 };
-use crate::types::{Chunk, PrivateChunk, PublicChunk};
+use crate::prefix_map::NetworkPrefixMap;
+use crate::types::PublicKey;
 
+use async_recursion::async_recursion;
 use bytes::Bytes;
 use futures::{future::join_all, stream::FuturesUnordered};
 use itertools::Itertools;
-use qp2p::Endpoint;
-use std::{collections::BTreeMap, net::SocketAddr};
-use tokio::{sync::mpsc::channel, task::JoinHandle, time::sleep};
+use qp2p::{Config as QuicP2pConfig, Endpoint};
+use std::{
+    collections::{BTreeMap, BTreeSet, HashMap},
+    net::SocketAddr,
+    sync::Arc,
+};
+use tokio::{
+    sync::mpsc::{channel, Sender},
+    sync::RwLock,
+    task::JoinHandle,
+    time::sleep,
+};
 use tracing::{debug, error, trace, warn};
 use xor_name::XorName;
 
@@ -28,8 +40,101 @@ use xor_name::XorName;
 const NUMBER_OF_RETRIES: usize = 3;
 // Number of Elders subset to send queries to
 const NUM_OF_ELDERS_SUBSET_FOR_QUERIES: usize = 3;
+// Number of attempts to make when trying to bootstrap to a section
+const NUM_OF_BOOTSTRAPPING_ATTEMPTS: u8 = 3;
 
 impl Session {
+    /// Acquire a session by bootstrapping to a section, maintaining connections to several nodes.
+    pub(crate) async fn bootstrap(
+        client_pk: PublicKey,
+        qp2p_config: QuicP2pConfig,
+        err_sender: Sender<CmdError>,
+        bootstrap_nodes: BTreeSet<SocketAddr>,
+        local_addr: SocketAddr,
+    ) -> Result<Session, Error> {
+        trace!(
+            "Trying to bootstrap to the network with public_key: {:?}",
+            client_pk
+        );
+        debug!("QP2p config: {:?}", qp2p_config);
+
+        let (endpoint, incoming_messages, _) = Endpoint::new_client(local_addr, qp2p_config)?;
+        let bootstrap_nodes = bootstrap_nodes.iter().copied().collect_vec();
+        let bootstrap_peer = endpoint
+            .connect_to_any(&bootstrap_nodes)
+            .await
+            .ok_or(Error::NotBootstrapped)?;
+
+        // *****************************************************
+        // FIXME: receive the network's genesis pk from the user
+        let genesis_pk = bls::SecretKey::random().public_key();
+        // *****************************************************
+
+        let session = Session {
+            client_pk,
+            pending_queries: Arc::new(RwLock::new(HashMap::default())),
+            incoming_err_sender: Arc::new(err_sender),
+            endpoint,
+            network: Arc::new(NetworkPrefixMap::new(genesis_pk)),
+            aggregator: Arc::new(RwLock::new(SignatureAggregator::new())),
+            bootstrap_peer,
+            genesis_pk,
+        };
+
+        Self::spawn_message_listener_thread(session.clone(), incoming_messages).await;
+
+        Ok(session)
+    }
+
+    /// Utility function that bootstraps a client to a section. If there is a failure then it retries.
+    /// After a maximum of three attempts if the boostrap process still fails, then an error is returned.
+    #[async_recursion]
+    pub(crate) async fn attempt_bootstrap(
+        client_pk: PublicKey,
+        qp2p_config: qp2p::Config,
+        mut bootstrap_nodes: BTreeSet<SocketAddr>,
+        local_addr: SocketAddr,
+        err_sender: Sender<CmdError>,
+        attempts: u8,
+    ) -> Result<Session, Error> {
+        match Session::bootstrap(
+            client_pk,
+            qp2p_config.clone(),
+            err_sender.clone(),
+            bootstrap_nodes.clone(),
+            local_addr,
+        )
+        .await
+        {
+            Ok(session) => Ok(session),
+            Err(err) => {
+                let attempts = attempts + 1;
+                if let Error::BootstrapToPeerFailed(failed_peer) = err {
+                    // Remove the unresponsive peer we boostrapped to and bootstrap again
+                    let _ = bootstrap_nodes.remove(&failed_peer);
+                }
+                if attempts < NUM_OF_BOOTSTRAPPING_ATTEMPTS {
+                    trace!(
+                        "Error connecting to network! {:?}\nRetrying... ({})",
+                        err,
+                        attempts
+                    );
+                    Self::attempt_bootstrap(
+                        client_pk,
+                        qp2p_config,
+                        bootstrap_nodes,
+                        local_addr,
+                        err_sender,
+                        attempts,
+                    )
+                    .await
+                } else {
+                    Err(err)
+                }
+            }
+        }
+    }
+
     /// Send a `ServiceMsg` to the network without awaiting for a response.
     pub(crate) async fn send_cmd(
         &self,
@@ -40,6 +145,8 @@ impl Session {
     ) -> Result<(), Error> {
         let endpoint = self.endpoint.clone();
 
+        // TODO: Consider other approach: Keep a session per section!
+
         // Get DataSection elders details.
         let (elders, section_pk) = if let Some(sap) = self.network.closest_or_opposite(&dst_address)
         {
@@ -89,21 +196,20 @@ impl Session {
         query: DataQuery,
         auth: ServiceAuth,
         payload: Bytes,
-        msg_id: MessageId,
     ) -> Result<QueryResult, Error> {
         let endpoint = self.endpoint.clone();
         let pending_queries = self.pending_queries.clone();
 
-        let chunk_addr = if let DataQuery::Chunk(ChunkRead::Get(address)) = query {
+        let chunk_addr = if let DataQuery::GetChunk(address) = query {
             Some(address)
         } else {
             None
         };
 
-        let data_name = query.dst_name();
+        let dst = query.dst_name();
 
         // Get DataSection elders details. Resort to own section if DataSection is not available.
-        let (elders, section_pk) = if let Some(sap) = self.network.closest_or_opposite(&data_name) {
+        let (elders, section_pk) = if let Some(sap) = self.network.closest_or_opposite(&dst) {
             (sap.value.elders, sap.value.public_key_set.public_key())
         } else {
             let mut bootstrapped_peer = BTreeMap::new();
@@ -115,23 +221,11 @@ impl Session {
         // We select the NUM_OF_ELDERS_SUBSET_FOR_QUERIES closest Elders we are querying
         let chosen_elders = elders
             .into_iter()
-            .sorted_by(|(lhs_name, _), (rhs_name, _)| data_name.cmp_distance(lhs_name, rhs_name))
+            .sorted_by(|(lhs_name, _), (rhs_name, _)| dst.cmp_distance(lhs_name, rhs_name))
             .map(|(_, addr)| addr)
             .take(NUM_OF_ELDERS_SUBSET_FOR_QUERIES)
             .collect::<Vec<SocketAddr>>();
 
-        let wire_msg = WireMsg::new_msg(
-            msg_id,
-            payload,
-            MsgKind::ServiceMsg(auth),
-            DstLocation::Section {
-                name: data_name,
-                section_pk,
-            },
-        )?;
-        let priority = wire_msg.msg_kind().priority();
-        let msg_bytes = wire_msg.serialize()?;
-
         let elders_len = chosen_elders.len();
         if elders_len < NUM_OF_ELDERS_SUBSET_FOR_QUERIES && elders_len > 1 {
             error!(
@@ -170,6 +264,15 @@ impl Session {
 
         let discarded_responses = std::sync::Arc::new(tokio::sync::Mutex::new(0_usize));
 
+        let dst_location = DstLocation::Section {
+            name: dst,
+            section_pk,
+        };
+        let msg_kind = MsgKind::ServiceMsg(auth);
+        let wire_msg = WireMsg::new_msg(msg_id, payload, msg_kind, dst_location)?;
+        let priority = wire_msg.msg_kind().priority();
+        let msg_bytes = wire_msg.serialize()?;
+
         // Set up response listeners
         for socket in chosen_elders {
             let endpoint = endpoint.clone();
@@ -178,7 +281,7 @@ impl Session {
             let task_handle = tokio::spawn(async move {
                 // Retry queries that failed due to connection issues only
                 let mut result = Err(Error::ElderQuery);
-                for attempt in 0..NUMBER_OF_RETRIES + 1 {
+                for attempt in 1..NUMBER_OF_RETRIES + 1 {
                     let msg_bytes_clone = msg_bytes.clone();
 
                     if let Err(err) = endpoint
@@ -187,9 +290,7 @@ impl Session {
                     {
                         error!(
                             "Try #{:?} @ {:?}, failed sending query message: {:?}",
-                            attempt + 1,
-                            socket,
-                            err
+                            attempt, socket, err
                         );
                         result = Err(Error::SendingQuery);
                         if attempt <= NUMBER_OF_RETRIES {
@@ -248,17 +349,7 @@ impl Session {
                     // matches its xorname, if so, we don't need to await for more responses
                     debug!("Chunk QueryResponse received is: {:#?}", chunk);
 
-                    let xorname = match &chunk {
-                        Chunk::Private(priv_chunk) => {
-                            *PrivateChunk::new(priv_chunk.value().clone(), *priv_chunk.owner())
-                                .name()
-                        }
-                        Chunk::Public(pub_chunk) => {
-                            *PublicChunk::new(pub_chunk.value().clone()).name()
-                        }
-                    };
-
-                    if *chunk_addr.name() == xorname {
+                    if chunk_addr.name() == chunk.name() {
                         trace!("Valid Chunk received for {}", msg_id);
                         break Some(QueryResponse::GetChunk(Ok(chunk)));
                     } else {
@@ -329,7 +420,6 @@ impl Session {
         for elder in peers {
             self.endpoint.disconnect_from(&elder).await;
         }
-
         Ok(())
     }
 }
