@@ -10,17 +10,10 @@ use bls::PublicKey as BlsPublicKey;
 use serde::{Deserialize, Serialize};
 use xor_name::{Prefix, XorName};
 
-/// This maps to the SocketAddr at the Elders where the EndUser is proxied through.
-pub type SocketId = XorName;
-
-/// An EndUser is represented by the name it's proxied through, and its socket id.
+/// An EndUser is represented by a name which is mapped to
+// a SocketAddr at the Elders where the `EndUser` is proxied through.
 #[derive(Clone, Copy, Eq, PartialEq, Hash, Serialize, Deserialize, Debug)]
-pub struct EndUser {
-    /// The name it's proxied through.
-    pub xorname: XorName,
-    /// This maps to the SocketAddr at the Elders where the `EndUser` is proxied through.
-    pub socket_id: SocketId,
-}
+pub struct EndUser(pub XorName);
 
 /// Message source location.
 #[derive(Clone, Copy, Eq, PartialEq, Hash, Serialize, Deserialize, Debug)]
@@ -47,7 +40,7 @@ impl SrcLocation {
     /// Returns the name of this location.
     pub fn name(&self) -> XorName {
         match self {
-            Self::EndUser(user) => user.xorname,
+            Self::EndUser(user) => user.0,
             Self::Node { name, .. } => *name,
             Self::Section { name, .. } => *name,
         }
@@ -84,10 +77,6 @@ pub enum DstLocation {
         /// Section's public key.
         section_pk: BlsPublicKey,
     },
-    /// Destination is a specific node to be directly connected to, and so the message is unrouted.
-    ///
-    /// The destination's known section key is provided.
-    DirectAndUnrouted(BlsPublicKey),
 }
 
 impl DstLocation {
@@ -97,7 +86,6 @@ impl DstLocation {
             Self::EndUser(_) => None,
             Self::Node { section_pk, .. } => Some(*section_pk),
             Self::Section { section_pk, .. } => Some(*section_pk),
-            Self::DirectAndUnrouted(section_pk) => Some(*section_pk),
         }
     }
 
@@ -107,7 +95,6 @@ impl DstLocation {
             Self::EndUser(_) => {}
             Self::Node { section_pk, .. } => *section_pk = pk,
             Self::Section { section_pk, .. } => *section_pk = pk,
-            Self::DirectAndUnrouted(section_pk) => *section_pk = pk,
         }
     }
 
@@ -118,34 +105,31 @@ impl DstLocation {
         }
 
         match self {
-            Self::EndUser(user) => prefix.matches(&user.xorname),
+            Self::EndUser(user) => prefix.matches(&user.0),
             Self::Node {
                 name: self_name, ..
             } => name == self_name,
             Self::Section {
                 name: self_name, ..
             } => prefix.matches(self_name),
-            Self::DirectAndUnrouted(_) => true,
         }
     }
 
     /// Returns the name of this location, or `None` if it is `Direct`.
     pub fn name(&self) -> Option<XorName> {
         match self {
-            Self::EndUser(user) => Some(user.xorname),
+            Self::EndUser(user) => Some(user.0),
             Self::Node { name, .. } => Some(*name),
             Self::Section { name, .. } => Some(*name),
-            Self::DirectAndUnrouted(_) => None,
         }
     }
 
-    /// Updates the name of this location if it's not `DirectAndUnrouted`.
+    /// Updates the name of this location.
     pub fn set_name(&mut self, new_name: XorName) {
         match self {
-            Self::EndUser(EndUser { xorname, .. }) => *xorname = new_name,
+            Self::EndUser(EndUser(name)) => *name = new_name,
             Self::Node { name, .. } => *name = new_name,
             Self::Section { name, .. } => *name = new_name,
-            Self::DirectAndUnrouted(_) => {}
         }
     }
 
