@@ -7,8 +7,11 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use crate::dbs::UsedSpace;
-use crate::messaging::data::StorageLevel;
-use crate::messaging::{data::ChunkDataExchange, system::SystemMsg, DstLocation, WireMsg};
+use crate::messaging::{
+    data::{ChunkDataExchange, StorageLevel},
+    system::SystemMsg,
+    DstLocation, WireMsg,
+};
 use crate::node::{state_db::store_network_keypair, Config as NodeConfig, Error, Result};
 use crate::routing::{
     ChunkStore, Config as RoutingConfig, Error as RoutingError, EventStream, PeerUtils,
@@ -17,12 +20,7 @@ use crate::routing::{
 use crate::types::PublicKey;
 use bls::{PublicKey as BlsPublicKey, PublicKeySet};
 use secured_linked_list::SecuredLinkedList;
-use std::{
-    collections::BTreeSet,
-    net::{Ipv4Addr, SocketAddr},
-    path::Path,
-    sync::Arc,
-};
+use std::{collections::BTreeSet, net::SocketAddr, path::Path, sync::Arc};
 use xor_name::{Prefix, XorName};
 
 ///
@@ -38,15 +36,16 @@ impl Network {
         config: &NodeConfig,
         used_space: UsedSpace,
     ) -> Result<(Self, EventStream)> {
-        let routing_config = RoutingConfig {
+        let mut routing_config = RoutingConfig {
             first: config.is_first(),
-            local_addr: config
-                .local_addr
-                .unwrap_or_else(|| SocketAddr::from((Ipv4Addr::LOCALHOST, 0))),
-            bootstrap_nodes: config.hard_coded_contacts.iter().copied().collect(),
-            transport_config: config.network_config().clone(),
-            keypair: None,
+            bootstrap_nodes: config.hard_coded_contacts.clone(),
+            network_config: config.network_config().clone(),
+            ..Default::default()
         };
+        if let Some(local_addr) = config.local_addr {
+            routing_config.local_addr = local_addr;
+        }
+
         let (routing, event_stream) =
             RoutingNode::new(routing_config, used_space, root_dir.to_path_buf()).await?;
 
