@@ -7,8 +7,8 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use crate::messaging::{
-    node::{
-        JoinRejectionReason, JoinRequest, JoinResponse, NodeMsg, ResourceProofResponse, Section,
+    system::{
+        JoinRejectionReason, JoinRequest, JoinResponse, ResourceProofResponse, Section, SystemMsg,
     },
     DstLocation, MessageType, MsgKind, NodeAuth, WireMsg,
 };
@@ -23,6 +23,8 @@ use crate::routing::{
     section::SectionUtils,
     SectionAuthorityProviderUtils, FIRST_SECTION_MAX_AGE, FIRST_SECTION_MIN_AGE, MIN_ADULT_AGE,
 };
+use crate::types::PublicKey;
+
 use bls::PublicKey as BlsPublicKey;
 use futures::future;
 use rand::seq::IteratorRandom;
@@ -279,10 +281,13 @@ impl<'a> Join<'a> {
     ) -> Result<()> {
         info!("Sending {:?} to {:?}", join_request, recipients);
 
-        let node_msg = NodeMsg::JoinRequest(Box::new(join_request));
+        let node_msg = SystemMsg::JoinRequest(Box::new(join_request));
         let wire_msg = WireMsg::single_src(
             &self.node,
-            DstLocation::DirectAndUnrouted(section_key),
+            DstLocation::Section {
+                name: XorName::from(PublicKey::Bls(section_key)),
+                section_pk: section_key,
+            },
             node_msg,
             section_key,
         )?;
@@ -300,7 +305,7 @@ impl<'a> Join<'a> {
             let (join_response, sender, src_name) = match event {
                 ConnectionEvent::Received((sender, bytes)) => match WireMsg::from(bytes) {
                     Ok(wire_msg) => match wire_msg.msg_kind() {
-                        MsgKind::ServiceMsg(_) | MsgKind::SectionInfoMsg => continue,
+                        MsgKind::ServiceMsg(_) => continue,
                         MsgKind::NodeBlsShareAuthMsg(_) | MsgKind::SectionAuthMsg(_) => {
                             trace!(
                                 "Bootstrap message discarded: sender: {:?} wire_msg: {:?}",
@@ -310,15 +315,14 @@ impl<'a> Join<'a> {
                             continue;
                         }
                         MsgKind::NodeAuthMsg(NodeAuth { .. }) => match wire_msg.into_message() {
-                            Ok(MessageType::Node {
-                                msg: NodeMsg::JoinResponse(resp),
+                            Ok(MessageType::System {
+                                msg: SystemMsg::JoinResponse(resp),
                                 msg_authority,
                                 ..
                             }) => (*resp, sender, msg_authority.src_location().name()),
                             Ok(
                                 MessageType::Service { msg_id, .. }
-                                | MessageType::SectionInfo { msg_id, .. }
-                                | MessageType::Node { msg_id, .. },
+                                | MessageType::System { msg_id, .. },
                             ) => {
                                 trace!(
                                     "Bootstrap message discarded: sender: {:?} msg_id: {:?}",
@@ -328,13 +332,13 @@ impl<'a> Join<'a> {
                                 continue;
                             }
                             Err(err) => {
-                                debug!("Failed to deserialize message payload: {}", err);
+                                debug!("Failed to deserialize message payload: {:?}", err);
                                 continue;
                             }
                         },
                     },
                     Err(err) => {
-                        debug!("Failed to deserialize message: {}", err);
+                        debug!("Failed to deserialize message: {:?}", err);
                         continue;
                     }
                 },
@@ -428,12 +432,13 @@ async fn send_messages(
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::messaging::{node::NodeState, SectionAuthorityProvider};
+    use crate::messaging::{system::NodeState, SectionAuthorityProvider};
     use crate::routing::{
         dkg::test_utils::*, error::Error as RoutingError, messages::WireMsgUtils,
         section::test_utils::*, section::NodeStateUtils, SectionAuthorityProviderUtils, ELDER_SIZE,
         MIN_ADULT_AGE, MIN_AGE,
     };
+    use crate::types::PublicKey;
     use assert_matches::assert_matches;
     use eyre::{eyre, Error, Result};
     use futures::{
@@ -482,17 +487,17 @@ mod tests {
                 recipients.iter().map(|(_name, addr)| *addr).collect();
             assert_eq!(bootstrap_addrs, [bootstrap_addr]);
 
-            let node_msg = assert_matches!(wire_msg.into_message(), Ok(MessageType::Node { msg, .. }) =>
+            let node_msg = assert_matches!(wire_msg.into_message(), Ok(MessageType::System { msg, .. }) =>
                 msg);
 
-            assert_matches!(node_msg, NodeMsg::JoinRequest(request) => {
+            assert_matches!(node_msg, SystemMsg::JoinRequest(request) => {
                 assert!(request.resource_proof_response.is_none());
             });
 
             // Send JoinResponse::Retry with section auth provider info
             send_response(
                 &recv_tx,
-                NodeMsg::JoinResponse(Box::new(JoinResponse::Retry(section_auth.clone()))),
+                SystemMsg::JoinResponse(Box::new(JoinResponse::Retry(section_auth.clone()))),
                 &bootstrap_node,
                 section_auth.section_key(),
             )?;
@@ -502,7 +507,7 @@ mod tests {
                 .recv()
                 .await
                 .ok_or_else(|| eyre!("JoinRequest was not received"))?;
-            let (node_msg, dst_location) = assert_matches!(wire_msg.into_message(), Ok(MessageType::Node { msg, dst_location,.. }) =>
+            let (node_msg, dst_location) = assert_matches!(wire_msg.into_message(), Ok(MessageType::System { msg, dst_location,.. }) =>
                 (msg, dst_location));
 
             assert_eq!(dst_location.section_pk(), Some(pk));
@@ -514,7 +519,7 @@ mod tests {
                     .map(|(name, addr)| (*name, *addr))
                     .collect::<Vec<_>>(),
             );
-            assert_matches!(node_msg, NodeMsg::JoinRequest(request) => {
+            assert_matches!(node_msg, SystemMsg::JoinRequest(request) => {
                 assert_eq!(request.section_key, pk);
             });
 
@@ -524,7 +529,7 @@ mod tests {
             let proof_chain = SecuredLinkedList::new(pk);
             send_response(
                 &recv_tx,
-                NodeMsg::JoinResponse(Box::new(JoinResponse::Approval {
+                SystemMsg::JoinResponse(Box::new(JoinResponse::Approval {
                     genesis_key: pk,
                     section_auth: section_auth.clone(),
                     node_state,
@@ -579,8 +584,8 @@ mod tests {
                 vec![bootstrap_node.addr]
             );
 
-            assert_matches!(wire_msg.into_message(), Ok(MessageType::Node { msg, .. }) =>
-                    assert_matches!(msg, NodeMsg::JoinRequest{..}));
+            assert_matches!(wire_msg.into_message(), Ok(MessageType::System { msg, .. }) =>
+                    assert_matches!(msg, SystemMsg::JoinRequest{..}));
 
             // Send JoinResponse::Redirect
             let new_bootstrap_addrs: BTreeMap<_, _> = (0..ELDER_SIZE)
@@ -589,11 +594,13 @@ mod tests {
 
             send_response(
                 &recv_tx,
-                NodeMsg::JoinResponse(Box::new(JoinResponse::Redirect(SectionAuthorityProvider {
-                    prefix: Prefix::default(),
-                    public_key_set: pk_set.clone(),
-                    elders: new_bootstrap_addrs.clone(),
-                }))),
+                SystemMsg::JoinResponse(Box::new(JoinResponse::Redirect(
+                    SectionAuthorityProvider {
+                        prefix: Prefix::default(),
+                        public_key_set: pk_set.clone(),
+                        elders: new_bootstrap_addrs.clone(),
+                    },
+                ))),
                 &bootstrap_node,
                 section_auth.section_key(),
             )?;
@@ -616,11 +623,11 @@ mod tests {
                     .collect::<Vec<_>>()
             );
 
-            let (node_msg, dst_location) = assert_matches!(wire_msg.into_message(), Ok(MessageType::Node { msg, dst_location,.. }) =>
+            let (node_msg, dst_location) = assert_matches!(wire_msg.into_message(), Ok(MessageType::System { msg, dst_location,.. }) =>
                     (msg, dst_location));
 
             assert_eq!(dst_location.section_pk(), Some(pk_set.public_key()));
-            assert_matches!(node_msg, NodeMsg::JoinRequest(req) => {
+            assert_matches!(node_msg, SystemMsg::JoinRequest(req) => {
                 assert_eq!(req.section_key, pk_set.public_key());
             });
 
@@ -659,16 +666,18 @@ mod tests {
                 .await
                 .ok_or_else(|| eyre!("JoinRequest was not received"))?;
 
-            assert_matches!(wire_msg.into_message(), Ok(MessageType::Node { msg, .. }) =>
-                        assert_matches!(msg, NodeMsg::JoinRequest{..}));
+            assert_matches!(wire_msg.into_message(), Ok(MessageType::System { msg, .. }) =>
+                        assert_matches!(msg, SystemMsg::JoinRequest{..}));
 
             send_response(
                 &recv_tx,
-                NodeMsg::JoinResponse(Box::new(JoinResponse::Redirect(SectionAuthorityProvider {
-                    prefix: Prefix::default(),
-                    public_key_set: pk_set.clone(),
-                    elders: BTreeMap::new(),
-                }))),
+                SystemMsg::JoinResponse(Box::new(JoinResponse::Redirect(
+                    SectionAuthorityProvider {
+                        prefix: Prefix::default(),
+                        public_key_set: pk_set.clone(),
+                        elders: BTreeMap::new(),
+                    },
+                ))),
                 &bootstrap_node,
                 section_auth.section_key(),
             )?;
@@ -680,11 +689,13 @@ mod tests {
 
             send_response(
                 &recv_tx,
-                NodeMsg::JoinResponse(Box::new(JoinResponse::Redirect(SectionAuthorityProvider {
-                    prefix: Prefix::default(),
-                    public_key_set: pk_set.clone(),
-                    elders: addrs,
-                }))),
+                SystemMsg::JoinResponse(Box::new(JoinResponse::Redirect(
+                    SectionAuthorityProvider {
+                        prefix: Prefix::default(),
+                        public_key_set: pk_set.clone(),
+                        elders: addrs,
+                    },
+                ))),
                 &bootstrap_node,
                 section_auth.section_key(),
             )?;
@@ -695,8 +706,8 @@ mod tests {
                 .await
                 .ok_or_else(|| eyre!("JoinRequest was not received"))?;
 
-            assert_matches!(wire_msg.into_message(), Ok(MessageType::Node { msg, .. }) =>
-                            assert_matches!(msg, NodeMsg::JoinRequest{..}));
+            assert_matches!(wire_msg.into_message(), Ok(MessageType::System { msg, .. }) =>
+                            assert_matches!(msg, SystemMsg::JoinRequest{..}));
 
             Ok(())
         };
@@ -733,12 +744,12 @@ mod tests {
                 .await
                 .ok_or_else(|| eyre!("JoinRequest was not received"))?;
 
-            assert_matches!(wire_msg.into_message(), Ok(MessageType::Node { msg, .. }) =>
-                                assert_matches!(msg, NodeMsg::JoinRequest{..}));
+            assert_matches!(wire_msg.into_message(), Ok(MessageType::System { msg, .. }) =>
+                                assert_matches!(msg, SystemMsg::JoinRequest{..}));
 
             send_response(
                 &recv_tx,
-                NodeMsg::JoinResponse(Box::new(JoinResponse::Rejected(
+                SystemMsg::JoinResponse(Box::new(JoinResponse::Rejected(
                     JoinRejectionReason::JoinsDisallowed,
                 ))),
                 &bootstrap_node,
@@ -799,13 +810,13 @@ mod tests {
                 .ok_or_else(|| eyre!("NodeMsg was not received"))?;
 
             let node_msg =
-                assert_matches!(wire_msg.into_message(), Ok(MessageType::Node{ msg, .. }) => msg);
-            assert_matches!(node_msg, NodeMsg::JoinRequest(_));
+                assert_matches!(wire_msg.into_message(), Ok(MessageType::System{ msg, .. }) => msg);
+            assert_matches!(node_msg, SystemMsg::JoinRequest(_));
 
             // Send `Retry` with bad prefix
             send_response(
                 &recv_tx,
-                NodeMsg::JoinResponse(Box::new(JoinResponse::Retry(
+                SystemMsg::JoinResponse(Box::new(JoinResponse::Retry(
                     gen_section_authority_provider(bad_prefix, ELDER_SIZE).0,
                 ))),
                 &bootstrap_node,
@@ -816,7 +827,7 @@ mod tests {
             // Send `Retry` with good prefix
             send_response(
                 &recv_tx,
-                NodeMsg::JoinResponse(Box::new(JoinResponse::Retry(
+                SystemMsg::JoinResponse(Box::new(JoinResponse::Retry(
                     gen_section_authority_provider(good_prefix, ELDER_SIZE).0,
                 ))),
                 &bootstrap_node,
@@ -829,8 +840,8 @@ mod tests {
                 .ok_or_else(|| eyre!("NodeMsg was not received"))?;
 
             let node_msg =
-                assert_matches!(wire_msg.into_message(), Ok(MessageType::Node{ msg, .. }) => msg);
-            assert_matches!(node_msg, NodeMsg::JoinRequest(_));
+                assert_matches!(wire_msg.into_message(), Ok(MessageType::System{ msg, .. }) => msg);
+            assert_matches!(node_msg, SystemMsg::JoinRequest(_));
 
             Ok(())
         };
@@ -847,13 +858,16 @@ mod tests {
     // test helper
     fn send_response(
         recv_tx: &mpsc::Sender<ConnectionEvent>,
-        node_msg: NodeMsg,
+        node_msg: SystemMsg,
         bootstrap_node: &Node,
         section_pk: BlsPublicKey,
     ) -> Result<()> {
         let wire_msg = WireMsg::single_src(
             bootstrap_node,
-            DstLocation::DirectAndUnrouted(section_pk),
+            DstLocation::Section {
+                name: XorName::from(PublicKey::Bls(section_pk)),
+                section_pk,
+            },
             node_msg,
             section_pk,
         )?;
