@@ -6,13 +6,13 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
+use super::NetworkPrefixMap;
 use crate::messaging::{
-    node::{Network, Peer, Section},
+    system::{Peer, Section},
     DstLocation,
 };
 use crate::routing::{
     error::{Error, Result},
-    network::NetworkUtils,
     peer::PeerUtils,
     section::{SectionPeersUtils, SectionUtils},
     supermajority, SectionAuthorityProviderUtils, ELDER_SIZE,
@@ -39,14 +39,14 @@ pub(crate) fn delivery_targets(
     dst: &DstLocation,
     our_name: &XorName,
     section: &Section,
-    network: &Network,
+    network: &NetworkPrefixMap,
 ) -> Result<(Vec<Peer>, usize)> {
     // Adult now having the knowledge of other adults within the own section.
     // Functions of `section_candidates` and `candidates` only take section elder into account.
 
     match dst {
         DstLocation::Section { name, .. } => section_candidates(name, our_name, section, network),
-        DstLocation::EndUser(user) => section_candidates(&user.xorname, our_name, section, network),
+        DstLocation::EndUser(user) => section_candidates(&user.0, our_name, section, network),
         DstLocation::Node { name, .. } => {
             if name == our_name {
                 return Ok((Vec::new(), 0));
@@ -65,7 +65,6 @@ pub(crate) fn delivery_targets(
                 candidates(name, our_name, section, network)
             }
         }
-        DstLocation::DirectAndUnrouted(_) => Err(Error::CannotRoute),
     }
 }
 
@@ -73,11 +72,12 @@ fn section_candidates(
     target_name: &XorName,
     our_name: &XorName,
     section: &Section,
-    network: &Network,
+    network: &NetworkPrefixMap,
 ) -> Result<(Vec<Peer>, usize)> {
     // Find closest section to `target_name` out of the ones we know (including our own)
+    let network_sections = network.all();
     let info = iter::once(section.authority_provider())
-        .chain(network.all())
+        .chain(network_sections.iter())
         .min_by(|lhs, rhs| lhs.prefix.cmp_distance(&rhs.prefix, target_name))
         .unwrap_or_else(|| section.authority_provider());
 
@@ -99,11 +99,12 @@ fn candidates(
     target_name: &XorName,
     our_name: &XorName,
     section: &Section,
-    network: &Network,
+    network: &NetworkPrefixMap,
 ) -> Result<(Vec<Peer>, usize)> {
     // All sections we know (including our own), sorted by distance to `target_name`.
+    let network_sections = network.all();
     let sections = iter::once(section.authority_provider())
-        .chain(network.all())
+        .chain(network_sections.iter())
         .sorted_by(|lhs, rhs| lhs.prefix.cmp_distance(&rhs.prefix, target_name))
         .map(|info| (&info.prefix, info.elder_count(), info.peers()));
 
@@ -149,18 +150,25 @@ fn candidates(
 }
 
 // Returns a `Peer` for a known node.
-fn get_peer(name: &XorName, section: &Section, network: &Network) -> Option<Peer> {
-    section
-        .members()
-        .get(name)
-        .map(|info| info.peer)
-        .or_else(|| network.get_elder(name))
+fn get_peer(name: &XorName, section: &Section, network: &NetworkPrefixMap) -> Option<Peer> {
+    match section.members().get(name) {
+        Some(info) => Some(info.peer),
+        None => network
+            .section_by_name(name)
+            .ok()?
+            .get_addr(name)
+            .map(|addr| {
+                let mut peer = Peer::new(*name, addr);
+                peer.set_reachable(true);
+                peer
+            }),
+    }
 }
 
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::messaging::{node::NodeState, SectionAuthorityProvider};
+    use crate::messaging::{system::NodeState, SectionAuthorityProvider};
     use crate::routing::{
         dkg::test_utils::section_signed,
         ed25519,
@@ -262,7 +270,7 @@ mod tests {
             .get(&Prefix::default().pushed(true))
             .context("unknown section")?;
 
-        let dst_name = choose_elder_name(section_auth1)?;
+        let dst_name = choose_elder_name(&section_auth1)?;
         let section_pk = section.authority_provider().section_key();
         let dst = DstLocation::Node {
             name: dst_name,
@@ -494,59 +502,68 @@ mod tests {
         Ok(())
     }
 
-    fn setup_elder() -> Result<(XorName, Section, Network, bls::SecretKey)> {
+    fn setup_elder() -> Result<(XorName, Section, NetworkPrefixMap, bls::SecretKey)> {
         let prefix0 = Prefix::default().pushed(false);
         let prefix1 = Prefix::default().pushed(true);
 
-        let genesis_sk = bls::SecretKey::random();
+        let (section_auth0, _, secret_key_set) =
+            gen_section_authority_provider(prefix0, ELDER_SIZE);
+        let genesis_sk = secret_key_set.secret_key();
         let genesis_pk = genesis_sk.public_key();
 
-        let sk = bls::SecretKey::random();
-        let pk = sk.public_key();
-
-        let (section_auth0, _, _) = gen_section_authority_provider(prefix0, ELDER_SIZE);
         let elders0: Vec<_> = section_auth0.peers().collect();
-        let section_auth0 = section_signed(&sk, section_auth0)?;
+        let section_auth0 = section_signed(genesis_sk, section_auth0)?;
 
-        let mut chain = SecuredLinkedList::new(genesis_pk);
-        let sig = bincode::serialize(&pk).map(|bytes| genesis_sk.sign(&bytes))?;
-        chain.insert(&genesis_pk, pk, sig)?;
-        let mut section = Section::new(pk, chain, section_auth0)?;
+        let chain = SecuredLinkedList::new(genesis_pk);
+
+        let mut section = Section::new(genesis_pk, chain, section_auth0)?;
 
         for peer in elders0 {
             let node_state = NodeState::joined(peer, None);
-            let node_state = section_signed(&sk, node_state)?;
+            let node_state = section_signed(genesis_sk, node_state)?;
             assert!(section.update_member(node_state));
         }
 
-        let mut network = Network::new();
+        let network = NetworkPrefixMap::new(genesis_pk);
 
-        let (section_auth1, _, _) = gen_section_authority_provider(prefix1, ELDER_SIZE);
-        let section_auth1 = section_signed(&sk, section_auth1)?;
+        let (section_auth1, _, secret_key_set) =
+            gen_section_authority_provider(prefix1, ELDER_SIZE);
+        let sk1 = secret_key_set.secret_key();
+        let pk1 = sk1.public_key();
+
+        let section_auth1 = section_signed(sk1, section_auth1)?;
+
+        // create a section chain branched out from same genesis pk
         let mut proof_chain = SecuredLinkedList::new(genesis_pk);
-        let pk1 = section_auth1.value.public_key_set.public_key();
-        let sig = bincode::serialize(&pk1).map(|bytes| genesis_sk.sign(&bytes))?;
-        proof_chain.insert(&genesis_pk, pk1, sig)?;
+        // second key is the PK derived from SAP's SK
+        let sig1 = bincode::serialize(&pk1).map(|bytes| genesis_sk.sign(&bytes))?;
+        proof_chain.insert(&genesis_pk, pk1, sig1)?;
 
-        assert!(network.update_remote_section_sap(section_auth1, &proof_chain, section.chain()));
+        // 3rd key is the section key in SAP
+        let pk2 = section_auth1.value.public_key_set.public_key();
+        let sig2 = bincode::serialize(&pk2).map(|bytes| sk1.sign(&bytes))?;
+        proof_chain.insert(&pk1, pk2, sig2)?;
+
+        assert!(network
+            .verify_with_chain_and_update(section_auth1, &proof_chain, section.chain())
+            .is_ok(),);
 
         let our_name = choose_elder_name(section.authority_provider())?;
 
-        Ok((our_name, section, network, sk))
+        Ok((our_name, section, network, genesis_sk.clone()))
     }
 
-    fn setup_adult() -> Result<(XorName, Section, Network)> {
+    fn setup_adult() -> Result<(XorName, Section, NetworkPrefixMap)> {
         let prefix0 = Prefix::default().pushed(false);
 
-        let sk = bls::SecretKey::random();
-        let pk = sk.public_key();
-        let chain = SecuredLinkedList::new(pk);
+        let (section_auth, _, secret_key_set) = gen_section_authority_provider(prefix0, ELDER_SIZE);
+        let genesis_sk = secret_key_set.secret_key();
+        let genesis_pk = genesis_sk.public_key();
+        let section_auth = section_signed(genesis_sk, section_auth)?;
+        let chain = SecuredLinkedList::new(genesis_pk);
+        let section = Section::new(genesis_pk, chain, section_auth)?;
 
-        let (section_auth, _, _) = gen_section_authority_provider(prefix0, ELDER_SIZE);
-        let section_auth = section_signed(&sk, section_auth)?;
-        let section = Section::new(pk, chain, section_auth)?;
-
-        let network = Network::new();
+        let network = NetworkPrefixMap::new(genesis_pk);
         let our_name = section.prefix().substituted_in(rand::random());
 
         Ok((our_name, section, network))
