@@ -6,7 +6,7 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use crate::messaging::node::{DkgFailureSig, DkgFailureSigSet, DkgKey, ElderCandidates};
+use crate::messaging::system::{DkgFailureSig, DkgFailureSigSet, DkgKey, ElderCandidates};
 use crate::routing::{
     ed25519::{self, Digest256, Keypair, Verifier},
     peer::PeerUtils,
