@@ -7,7 +7,7 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use crate::messaging::{
-    node::{DkgFailureSig, DkgFailureSigSet, DkgKey, ElderCandidates, NodeMsg},
+    system::{DkgFailureSig, DkgFailureSigSet, DkgKey, ElderCandidates, SystemMsg},
     DstLocation, SectionAuthorityProvider, WireMsg,
 };
 use crate::routing::{
@@ -20,6 +20,7 @@ use crate::routing::{
     section::SectionKeyShare,
     SectionAuthorityProviderUtils,
 };
+use crate::types::PublicKey;
 use bls::PublicKey as BlsPublicKey;
 use bls_dkg::key_gen::{message::Message as DkgMessage, KeyGen};
 use itertools::Itertools;
@@ -102,14 +103,22 @@ impl Session {
 
         let recipients = self.recipients();
         if !recipients.is_empty() {
-            trace!("broadcasting DKG message {:?} to {:?}", message, recipients);
-            let node_msg = NodeMsg::DkgMessage {
+            trace!(
+                "DKG broadcasting {:?} - {:?} to {:?}",
+                message,
+                dkg_key,
+                recipients
+            );
+            let node_msg = SystemMsg::DkgMessage {
                 dkg_key: *dkg_key,
                 message: message.clone(),
             };
             let wire_msg = WireMsg::single_src(
                 node,
-                DstLocation::DirectAndUnrouted(section_pk),
+                DstLocation::Section {
+                    name: XorName::from(PublicKey::Bls(section_pk)),
+                    section_pk,
+                },
                 node_msg,
                 section_pk,
             )?;
@@ -134,7 +143,7 @@ impl Session {
             return Ok(vec![]);
         }
 
-        trace!("DKG for {:?} progressing", self.elder_candidates);
+        trace!("DKG progressing for {:?}", self.elder_candidates);
 
         match self.key_gen.timed_phase_transition(&mut rand::thread_rng()) {
             Ok(messages) => {
@@ -147,7 +156,7 @@ impl Session {
                 Ok(commands)
             }
             Err(error) => {
-                trace!("DKG for {:?} failed: {}", self.elder_candidates, error);
+                trace!("DKG failed for {:?}: {}", self.elder_candidates, error);
                 self.report_failure(node, dkg_key, BTreeSet::new(), section_pk)
             }
         }
@@ -177,7 +186,7 @@ impl Session {
         // Less than 100% participation
         if !participants.iter().eq(self.elder_candidates.elders.keys()) {
             trace!(
-                "DKG for {:?} failed: unexpected participants: {:?}",
+                "DKG failed due to unexpected participants for {:?}: {:?}",
                 self.elder_candidates,
                 participants.iter().format(", ")
             );
@@ -208,14 +217,14 @@ impl Session {
             != outcome.secret_key_share.public_key_share()
         {
             trace!(
-                "DKG for {:?} failed: corrupted outcome",
+                "DKG failed due to corrupted outcome for {:?}",
                 self.elder_candidates
             );
             return self.report_failure(node, dkg_key, BTreeSet::new(), section_pk);
         }
 
         trace!(
-            "DKG for {:?} complete: {:?}",
+            "DKG complete for {:?}: {:?}",
             self.elder_candidates,
             outcome.public_key_set.public_key()
         );
@@ -255,14 +264,17 @@ impl Session {
             .check_failure_agreement()
             .into_iter()
             .chain(iter::once({
-                let node_msg = NodeMsg::DkgFailureObservation {
+                let node_msg = SystemMsg::DkgFailureObservation {
                     dkg_key: *dkg_key,
                     sig,
                     failed_participants,
                 };
                 let wire_msg = WireMsg::single_src(
                     node,
-                    DstLocation::DirectAndUnrouted(section_pk),
+                    DstLocation::Section {
+                        name: XorName::from(PublicKey::Bls(section_pk)),
+                        section_pk,
+                    },
                     node_msg,
                     section_pk,
                 )?;
@@ -485,8 +497,8 @@ mod tests {
                     recipients,
                     wire_msg,
                 } => match wire_msg.into_message()? {
-                    MessageType::Node {
-                        msg: NodeMsg::DkgMessage { dkg_key, message },
+                    MessageType::System {
+                        msg: SystemMsg::DkgMessage { dkg_key, message },
                         ..
                     } => {
                         assert_eq!(dkg_key, *expected_dkg_key);
